A simple function that plots the log2 RPF-to-mRNA ratios in two conditions. Different classes of genes are labeled with different of color. Each dot, representing a particular gene, are color coded by the category of expression change.
plotRs(object, ...) # S4 method for xtail plotRs(object, log2R.cutoff = 1, xlim = NULL, ylim = NULL)
| object | a |
|---|---|
| ... | optional arguments. Currently not used |
| log2R.cutoff | cutoff for categorizing results |
| xlim | argument for limiting the range plotted on the x axis. See
|
| ylim | argument for limiting the range plotted on the y axis. See
|
a ggplot object